import { waitForIt, api } from "zen-cerebellum";

import { restoreSession } from "./auth";

//WAA : read settings of authentified user
export const loadSettings = () => api.get("SETTINGS", "/settings");

//WAA : clear the back-office cache. USE WITH CAUTION !
export const reloadPRM = () => api.post("RELOAD_PRM", "/cache/reloadPRM");

//WAA : show product versions
export const loadVersions = () => api.get("VERSIONS", "/version");

//RAA : load available instances
export function loadInstances() {
  return api.dispatch(({ instances }) => {
    if (instances.length === 0) return api.get("INSTANCES", "/instances");
  });
}

//WAA : read local configuration
function fetchConfig() {
  return api.get("CONFIG", "*/config.json", null, { restricted: false });
}

//RAA : initialize workflow
export function initFlow(token, initTheme) {
  return dispatch => {
    return waitForIt((resolve, reject) => {
      //retrieve configuration file
      dispatch(fetchConfig()).then(cfg => {
        //inject theme
        initTheme(cfg);
        //then try to restore session
        dispatch(restoreSession(token))
          //set promise as resolved or rejected
          .then(x => resolve(x))
          .catch(e => reject(e));
      });
    });
  };
}
