import { createStore, applyMiddleware, compose } from "redux";
import webApi from "zen-cortex/api/web-api";

const composeEnhancers =
  process.env.NODE_ENV !== "production" &&
  window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__
    ? window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__
    : compose;

/**
 * Configure REDUX store (single source of truth)
 *
 * @param {object} rootReducer - main reducer to rule them all
 * @param {func} asyncMiddleware - asynchronous actions handler (ex : redux-thunk)
 * @param {object} [initialState] - state initial state
 */
export default function configureStore(
  rootReducer,
  asyncMiddleware,
  initialState
) {
  return createStore(
    rootReducer,
    initialState,
    composeEnhancers(applyMiddleware(asyncMiddleware, webApi))
  );
}
